@@ -25,7 +25,7 @@ InputEventHandler.  The listeners field is a dictionary where the keys
 are AT-SPI event names and the values are function pointers.
 
 Instances of scripts are intended to be created solely by the
-focus_tracking_presenter.
+script manager.
 
 This Script class is not intended to be instantiated directly.
 Instead, it is expected that subclasses of the Script class will be
@@ -62,7 +62,7 @@ class Script:
     def __init__(self, app):
         """Creates a script for the given application, if necessary.
         This method should not be called by anyone except the
-        focus_tracking_presenter.
+        script manager.
 
         Arguments:
         - app: the Python Accessible application to create a script for
@@ -110,15 +110,6 @@ class Script:
 
         self.findCommandRun = False
 
-        # Assists with dealing with CORBA COMM_FAILURES.  A failure doesn't
-        # always mean an object disappeared - there just might be a network
-        # glitch.  So, on COMM_FAILURES, we might retry a few times before
-        # giving up on an object.  This might need to be overridden by the
-        # script.  See bug #397787.
-        #
-        self.commFailureWaitTime = settings.commFailureWaitTime
-        self.commFailureAttemptLimit = settings.commFailureAttemptLimit
-
         debug.println(debug.LEVEL_FINE, "NEW SCRIPT: %s" % self.name)
 
     def getListeners(self):
@@ -271,7 +262,7 @@ class Script:
             return self.bookmarks
 
     def getAppPreferencesGUI(self):
-        """Return a GtkVBox contain the application unique configuration
+        """Return a GtkGrid containing the application unique configuration
         GUI items for the current application.
         """
         return None
@@ -331,11 +322,15 @@ class Script:
         whether or not the script is active.
         """
 
+        import orca
+        _scriptManager = getattr(orca, '_scriptManager')
+        _settingsManager = getattr(orca, '_settingsManager')
+
         scriptSettings = settings
         if orca_state.activeScript != self:
-            name = settings.getScriptModuleName(self.app)
+            name = _scriptManager.getModuleName(self.app)
             if name:
-                for package in settings.settingsPackages:
+                for package in _settingsManager.settingsPackages:
                     name = package + "." + name
                     try:
                         module = __import__(name, globals(), locals(), [''])
@@ -361,11 +356,6 @@ class Script:
         'listeners' field that was defined during the construction of
         this script.
 
-        In general, the primary purpose of handling object events is to
-        keep track of changes to the locus of focus and notify the
-        orca module of these changes via orca.setLocusOfFocus and
-        orca.visualAppearanceChanged.
-
         Note that this script may be passed events it doesn't care
         about, so it needs to react accordingly.
 
@@ -456,8 +446,8 @@ class Script:
         """
 
         try:
-            import gtk.gdk as gdk
-            keyboardEvent.keyval_name = gdk.keyval_name(keyboardEvent.id)
+            from gi.repository import Gdk
+            keyboardEvent.keyval_name = Gdk.keyval_name(keyboardEvent.id)
         except:
             debug.println(debug.LEVEL_FINE,
                           "Could not obtain keyval_name for id: %d" \
@@ -643,10 +633,6 @@ class Script:
         The primary purpose of this method is to present the changed
         information to the user.
 
-        NOTE: scripts should not call this method directly.  Instead,
-        a script should call orca.visualAppearanceChanged, which will
-        eventually result in this method being called.
-
         Arguments:
         - event: if not None, the Event that caused this to happen
         - obj: the Accessible whose visual appearance changed.
