@@ -3,16 +3,16 @@
 # Copyright 2010 Joanmarie Diggs.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -213,6 +213,41 @@ class Utilities(script_utilities.Utilities):
 
         return None
 
+    def grabFocusBeforeRouting(self, obj, offset):
+        """Whether or not we should perform a grabFocus before routing
+        the cursor via the braille cursor routing keys.
+
+        Arguments:
+        - obj: the accessible object where the cursor should be routed
+        - offset: the offset to which it should be routed
+
+        Returns True if we should do an explicit grabFocus on obj prior
+        to routing the cursor.
+        """
+
+        if obj and obj.getRole() == pyatspi.ROLE_COMBO_BOX \
+           and not self.isSameObject(obj, orca_state.locusOfFocus):
+            return True
+
+        return False
+
+    def isEntry(self, obj):
+        """Returns True if we should treat this object as an entry."""
+
+        if not obj:
+            return False
+
+        if obj.getRole() == pyatspi.ROLE_ENTRY:
+            return True
+
+        if obj.getState().contains(pyatspi.STATE_EDITABLE) \
+           and obj.getRole() in [pyatspi.ROLE_DOCUMENT_FRAME,
+                                 pyatspi.ROLE_PARAGRAPH,
+                                 pyatspi.ROLE_TEXT]:
+            return True
+
+        return False
+
     def isLayoutOnly(self, obj):
         """Returns True if the given object is for layout purposes only."""
 
@@ -224,6 +259,11 @@ class Utilities(script_utilities.Utilities):
         else:
             return script_utilities.Utilities.isLayoutOnly(self, obj)
 
+    def isPasswordText(self, obj):
+        """Returns True if we should treat this object as password text."""
+
+        return obj and obj.getRole() == pyatspi.ROLE_PASSWORD_TEXT
+
     def isReadOnlyTextArea(self, obj):
         """Returns True if obj is a text entry area that is read only."""
 
@@ -233,9 +273,10 @@ class Utilities(script_utilities.Utilities):
         state = obj.getState()
         readOnly = state.contains(pyatspi.STATE_FOCUSABLE) \
                    and not state.contains(pyatspi.STATE_EDITABLE)
+        details = debug.getAccessibleDetails(debug.LEVEL_ALL, obj)
         debug.println(debug.LEVEL_ALL,
                       "Gecko - isReadOnlyTextArea=%s for %s" \
-                      % (readOnly, debug.getAccessibleDetails(obj)))
+                      % (readOnly, details))
 
         return readOnly
 
